@@ -5,4 +5,4 @@ pycraigslist.models
 A suite of modules that interface with the Craigslist API.
 """
 
-from . import filters, search, search_detail
+from pycraigslist.models import filters, search, search_detail
