@@ -5,4 +5,4 @@ pycraigslist.tests.specs
 A suite of modules that stores test data and utility methods.
 """
 
-from .static import *
+from tests.specs.static import *
